unit rDialogsEx;

{<
  rDialogsEx contains rOpenDialog and rSaveDialog used in all rosi components
  and provide setting centralization for dialogs properties.

  Updated version compatible with Delphi2010+.
  @author(Rosinsky Software - <http://www.rosinsky.cz/delphi>)
  @created(Oct 2011)
  @lastmod(Jan 2013)
}

interface

uses
  Windows, Messages, SysUtils, Graphics, Classes, Controls, Menus,
  StdCtrls, ComCtrls, Buttons, Forms, Dialogs, RosiCompGlobalCfg;

type
  TrOpenDialog = class(TOpenDialog)
  public
    constructor Create(AOwner: TComponent); override;
  end;

  TrSaveDialog = class(TSaveDialog)
  public
    constructor Create(AOwner: TComponent); override;
  end;

function BrowseForFolder(const Title: string; const IniFolder: string = ''): string;
function BrowseForFolderEx(const Title: string; const IniFolder: string = ''): string;

function ShowSelectFontDialog(AFont: TFont): boolean;

implementation

uses shlobj;

var
  lg_StartFolder: string;

constructor TrOpenDialog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Options:=RosiCompConfig.rDBToolCfg.FileDialog_Options;
  if Assigned(RosiCompConfig.rDBToolCfg.FileDialog_InitDialogEvent) then
    RosiCompConfig.rDBToolCfg.FileDialog_InitDialogEvent(Self);
end;

constructor TrSaveDialog.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Options:=RosiCompConfig.rDBToolCfg.FileDialog_Options;
  if Assigned(RosiCompConfig.rDBToolCfg.FileDialog_InitDialogEvent) then
    RosiCompConfig.rDBToolCfg.FileDialog_InitDialogEvent(Self);
end;

function BrowseForFolderCallBack(Wnd: HWND; uMsg: UINT; lParam, lpData: lParam): integer stdcall;
begin
  if uMsg = BFFM_INITIALIZED then
    SendMessage(Wnd, BFFM_SETSELECTION, 1, integer(@lg_StartFolder[1]));
  Result:=0;
end;

function BrowseForFolder(const Title: string; const IniFolder: string = ''): string;
var
  browse_info: TBrowseInfo;
  folder: array [0 .. MAX_PATH] of Char;
  find_context: PItemIDList;
begin
  FillChar(browse_info, SizeOf(browse_info), #0);
  lg_StartFolder:=IniFolder;
  browse_info.pszDisplayName:=@folder[0];
  browse_info.lpszTitle:=PChar(Title);
  browse_info.ulFlags:=BIF_RETURNONLYFSDIRS;
  browse_info.hwndOwner:=Application.Handle;
  if IniFolder <> '' then
    browse_info.lpfn:=BrowseForFolderCallBack;
  find_context:=SHBrowseForFolder(browse_info);
  if Assigned(find_context) then
  begin
    if SHGetPathFromIDList(find_context, folder) then
      Result:=folder
    else
      Result:='';
    GlobalFreePtr(find_context);
  end
  else
    Result:='';
end;

{$WARN SYMBOL_PLATFORM OFF}
function BrowseForFolderEx(const Title: string; const IniFolder: string = ''): string;
var
  Dlg: TFileOpenDialog;
begin
  Dlg:=TFileOpenDialog.Create(nil);
  try
    Dlg.Options := [fdoPickFolders];
    Dlg.Title:=Title;
    Dlg.DefaultFolder:=IniFolder;
    if Dlg.Execute then
      Result:=Dlg.FileName
    else
      Result:='';
  finally
    Dlg.Free;
  end;
end;
{$WARN SYMBOL_PLATFORM ON}

function ShowSelectFontDialog(AFont: TFont): boolean;
var
  D: TFontDialog;
begin
  D:=TFontDialog.Create(Application);
  try
    D.Font.Assign(AFont);
    Result:=D.Execute;
    if Result then
      AFont.Assign(D.Font);
  finally
    D.Free;
  end;
end;

end.
